<?php

namespace Bixo\Shop\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Bixo\Shop\Forms\Accessory as AccessoryForm;
use Bixo\Shop\Http\Requests\AccessoryResourceRequest;
use Bixo\Shop\Http\Resources\AccessoryResource;
use Bixo\Shop\Http\Resources\AccessoriesCollection;
use Bixo\Shop\Models\Accessory;
use Bixo\Shop\Actions\AccessoryAction;
use Bixo\Shop\Actions\AccessoryActions;


/**
 * Resource controller class for accessory.
 */
class AccessoryResourceController extends BaseController
{

    /**
     * Initialize accessory resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = AccessoryForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('bixo.shop.modules'), 'shop', guard_url('shop'));
            return $next($request);
        });
    }

    /**
     * Display a list of accessory.
     *
     * @return Response
     */
    public function index(AccessoryResourceRequest $request)
    {
        $request = $request->all();
        $page = AccessoryActions::run('paginate', $request);

        $data = new AccessoriesCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('shop::accessory.names'))
            ->view('shop::accessory.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display accessory.
     *
     * @param Request $request
     * @param Model   $accessory
     *
     * @return Response
     */
    public function show(AccessoryResourceRequest $request, Accessory $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new AccessoryResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('shop::accessory.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('shop::accessory.show')
            ->output();
    }

    /**
     * Show the form for creating a new accessory.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AccessoryResourceRequest $request, Accessory $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new AccessoryResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('shop::accessory.name'))
            ->view('shop::accessory.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new accessory.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AccessoryResourceRequest $request, Accessory $model)
    {
        try {
            $request = $request->all();
            $model = AccessoryAction::run('store', $model, $request);
            $data = new AccessoryResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('shop::accessory.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('shop/accessory/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/shop/accessory'))
                ->redirect();
        }

    }

    /**
     * Show accessory for editing.
     *
     * @param Request $request
     * @param Model   $accessory
     *
     * @return Response
     */
    public function edit(AccessoryResourceRequest $request, Accessory $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new AccessoryResource($model);
        // return view('shop::accessory.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('shop::accessory.name'))
            ->view('shop::accessory.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the accessory.
     *
     * @param Request $request
     * @param Model   $accessory
     *
     * @return Response
     */
    public function update(AccessoryResourceRequest $request, Accessory $model)
    {
        try {
            $request = $request->all();
            $model = AccessoryAction::run('update', $model, $request);
            $data = new AccessoryResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('shop::accessory.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('shop/accessory/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('shop/accessory/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the accessory.
     *
     * @param Model   $accessory
     *
     * @return Response
     */
    public function destroy(AccessoryResourceRequest $request, Accessory $model)
    {
        try {

            $request = $request->all();
            $model = AccessoryAction::run('destroy', $model, $request);
            $data = new AccessoryResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('shop::accessory.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('shop/accessory/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('shop/accessory/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
