<?php

namespace Bixo\Shop\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Shop\Actions\SparePartAction;
use Bixo\Shop\Http\Requests\SparePartActionRequest;
use Bixo\Shop\Http\Resources\SparePartResource;
use Bixo\Shop\Models\SparePart;

/**
 * Admin web controller class.
 */
class SparePartActionController extends BaseController
{

    /**
     * Action controller function for spare_part.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(SparePartActionRequest $request, SparePart $spare_part, $action)
    {
        try {
            $request = $request->all();
            $spare_part = SparePartAction::run($action, $spare_part, $request);

            $data = new SparePartResource($spare_part);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('shop::spare_part.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('shop/spare_part/' . $spare_part->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('shop/spare_part/' . $spare_part->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
