<?php

namespace Bixo\Shop\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Bixo\Shop\Actions\SparePartExim;
use Bixo\Shop\Http\Requests\SparePartEximRequest;

/**
 * Admin web controller class.
 */
class SparePartEximController extends BaseController
{
    /**
     * Action controller function for spare_part.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(SparePartEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = SparePartExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('shop:spare_part.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('shop/spare_part/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('shop/spare_part/' . $exim))
                ->redirect();
        }
    }
}
