<?php

namespace Bixo\Shop\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Shop\Http\Resources\ShopResource;
use Bixo\Shop\Http\Resources\ShopsCollection;
use Bixo\Shop\Scopes\SparePartPublicScope;
use Bixo\Shop\Models\SparePart;

class SparePartPublicController extends BaseController
{

    /**
     * Show spare_part's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = SparePart::pushScope(new RequestScope())
            ->pushScope(new SparePartPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $spare_parts = new SparePartsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('shop::spare_part.names'))
            ->view('shop::public.spare_part.index')
            ->data(compact('spare_parts', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show spare_part.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = SparePart::findBySlug($slug);
        $data = new SparePartResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('shop::spare_part.name'))
            ->view('shop::public.spare_part.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
