<?php

namespace Bixo\Shop\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Shop\Events\AccessoryAction as AccessoryActionEvent;
use Bixo\Shop\Notifications\AccessoryAction as AccessoryActionNotification;
use Litepie\Actions\Concerns\AsAction;

class AccessoryAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the AccessoryActionEvent.
     *
     * @param   AccessoryActionEvent  $event
     * @return mixed
     */
    public function handle(AccessoryActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $accessory.
     *
     * @param   AccessoryActionEvent  $event
     * @return void
     */
    public function create(AccessoryActionEvent $event)
    {
        $client = $event->accessory->client;
        Notification::send($client, new AccessoryActionNotification($event));
    }

    /**
     * Handle the AccessoryActionEvent as a listener.
     *
     * @param   AccessoryActionEvent  $event
     * @return mixed
     */
    public function asListener(AccessoryActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   AccessoryActionEvent  $event
     * @return bool
     */
    private function isAllowed(AccessoryActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
