<?php

namespace Bixo\Shop\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Shop\Events\AccessoryWorkflow as AccessoryWorkflowEvent;
use Bixo\Shop\Notifications\AccessoryWorkflow as AccessoryWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class AccessoryWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(AccessoryWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $accessory is submitted.
     *
     * @param AccessoryWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(AccessoryWorkflowEvent $event)
    {
        $client = $event->accessory->client;
        Notification::send($client, new AccessoryWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $accessory is published.
     *
     * @param AccessoryWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(AccessoryWorkflowEvent $event)
    {
        $client = $event->accessory->client;
        Notification::send($client, new AccessoryWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $accessory is approved.
     *
     * @param AccessoryWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(AccessoryWorkflowEvent $event)
    {
        $client = $event->accessory->client;
        Notification::send($client, new AccessoryWorkflowNotification($event));
    }

    /**
     * Handles the $accessory workflow event as a listener.
     *
     * @param AccessoryWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(AccessoryWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
