<?php

namespace Bixo\Shop\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Shop\Events\ServiceKitWorkflow as ServiceKitWorkflowEvent;
use Bixo\Shop\Notifications\ServiceKitWorkflow as ServiceKitWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ServiceKitWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ServiceKitWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $service_kit is submitted.
     *
     * @param ServiceKitWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ServiceKitWorkflowEvent $event)
    {
        $client = $event->service_kit->client;
        Notification::send($client, new ServiceKitWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $service_kit is published.
     *
     * @param ServiceKitWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ServiceKitWorkflowEvent $event)
    {
        $client = $event->service_kit->client;
        Notification::send($client, new ServiceKitWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $service_kit is approved.
     *
     * @param ServiceKitWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ServiceKitWorkflowEvent $event)
    {
        $client = $event->service_kit->client;
        Notification::send($client, new ServiceKitWorkflowNotification($event));
    }

    /**
     * Handles the $service_kit workflow event as a listener.
     *
     * @param ServiceKitWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ServiceKitWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
