<?php

namespace Bixo\Shop\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Shop\Events\SparePartWorkflow as SparePartWorkflowEvent;
use Bixo\Shop\Notifications\SparePartWorkflow as SparePartWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class SparePartWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(SparePartWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $spare_part is submitted.
     *
     * @param SparePartWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(SparePartWorkflowEvent $event)
    {
        $client = $event->spare_part->client;
        Notification::send($client, new SparePartWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $spare_part is published.
     *
     * @param SparePartWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(SparePartWorkflowEvent $event)
    {
        $client = $event->spare_part->client;
        Notification::send($client, new SparePartWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $spare_part is approved.
     *
     * @param SparePartWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(SparePartWorkflowEvent $event)
    {
        $client = $event->spare_part->client;
        Notification::send($client, new SparePartWorkflowNotification($event));
    }

    /**
     * Handles the $spare_part workflow event as a listener.
     *
     * @param SparePartWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(SparePartWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
