<?php

namespace Bixo\Shop\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Shop\Models\ServiceKit;

class ServiceKitPolicy
{


    /**
     * Determine if the given user can view the service_kit.
     *
     * @param Authenticatable $user
     * @param ServiceKit $service_kit
     *
     * @return bool
     */
    public function view(Authenticatable $user, ServiceKit $service_kit)
    {
        if ($authUser->canDo('shop.service_kit.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $service_kit->is_owner;
    }

    /**
     * Determine if the given user can create a service_kit.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('shop.service_kit.create');
    }

    /**
     * Determine if the given user can update the given service_kit.
     *
     * @param Authenticatable $user
     * @param ServiceKit $service_kit
     *
     * @return bool
     */
    public function update(Authenticatable $user, ServiceKit $service_kit)
    {
        if ($user->canDo('shop.service_kit.edit') && $user->isAdmin()) {
            return true;
        }

        return $service_kit->is_owner;
    }

    /**
     * Determine if the given user can delete the given service_kit.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, ServiceKit $service_kit)
    {
        return $service_kit->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
