<?php

namespace Bixo\Shop\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Shop\Models\SparePart;

class SparePartPolicy
{

    use SparePartAction;
    use SparePartExim;
    use SparePartReport;
    use SparePartWorkflow;

    /**
     * Determine if the given user can view the spare_part.
     *
     * @param Authenticatable $user
     * @param SparePart $spare_part
     *
     * @return bool
     */
    public function view(Authenticatable $user, SparePart $spare_part)
    {
        if ($authUser->canDo('shop.spare_part.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $spare_part->is_owner;
    }

    /**
     * Determine if the given user can create a spare_part.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('shop.spare_part.create');
    }

    /**
     * Determine if the given user can update the given spare_part.
     *
     * @param Authenticatable $user
     * @param SparePart $spare_part
     *
     * @return bool
     */
    public function update(Authenticatable $user, SparePart $spare_part)
    {
        if ($user->canDo('shop.spare_part.edit') && $user->isAdmin()) {
            return true;
        }

        return $spare_part->is_owner;
    }

    /**
     * Determine if the given user can delete the given spare_part.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, SparePart $spare_part)
    {
        return $spare_part->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
